import { spawn } from 'node:child_process';
import react from '@astrojs/react';
import AdminDashboard from './vite-plugin-admin-dashboard.js';
const widgetPath = 'astro-netlify-cms/identity-widget';
export default function NetlifyCMS({ adminPath = '/admin', config: cmsConfig, previewStyles = [], }) {
    const NetlifyCMSIntegration = {
        name: 'netlify-cms',
        hooks: {
            'astro:config:setup': ({ config, injectScript, updateConfig }) => {
                var _a;
                const newConfig = {
                    // Default to the URL provided by Netlify when building there. See:
                    // https://docs.netlify.com/configure-builds/environment-variables/#deploy-urls-and-metadata
                    site: config.site || process.env.URL,
                    vite: {
                        plugins: [
                            ...(((_a = config.vite) === null || _a === void 0 ? void 0 : _a.plugins) || []),
                            AdminDashboard({
                                adminPath,
                                config: cmsConfig,
                                previewStyles,
                            }),
                        ],
                    },
                };
                updateConfig(newConfig);
                injectScript('page', `import { initIdentity } from '${widgetPath}'; initIdentity('${adminPath}')`);
            },
            'astro:server:start': () => {
                const proxy = spawn('netlify-cms-proxy-server', {
                    stdio: 'inherit',
                    // Run in shell on Windows to make sure the npm package can be found.
                    shell: process.platform === 'win32',
                });
                process.on('exit', () => proxy.kill());
            },
        },
    };
    return [react(), NetlifyCMSIntegration];
}
